import axios from 'axios'
import airlst from 'airlst-sdk'

const apiClient = axios.create({
    baseURL: process.env.API_URL,
    withCredentials: false,
    headers: {
        Accept: 'application/json',
        'Content-Type': 'application/json'
    }
});

const sdk = new airlst(apiClient);

export default {

    // initSdk(env, company_uid, quest_list_uid) {
    //     sdk.apiUrl = env.VUE_APP_API_URL;
    //     sdk.companyUid = company_uid;
    //     sdk.guestlistUid = quest_list_uid;
    // },

    initSdk(env, company_uid, quest_list_uid) {
        sdk.apiUrl = 'https://v1.api.airlst.com/lp';
        sdk.companyUid = 'ANDHYS8';
        sdk.guestlistUid = 'ZB6RWQOHAY';
    },

    checkPassword(password) {

        let headers = {
            Accept: 'application/json',
            'Content-Type': 'application/json',
            'x-airlst-company': sdk.companyUid
        };

        return apiClient.post(`${sdk.apiUrl}/guestlists/${sdk.guestlistUid}/check-password`,
            { password: password},
            {headers: headers});
    },

    retrieveStateDataFromApi(){
        return sdk.retrieveGuestlistInformation();
    },

    retrieveRsvpInformation(rsvpCode){
        return sdk.retrieveRsvpInformation(rsvpCode);
    },

    updateRsvpByCode(rsvpCode, data){
        return sdk.updateRsvpByCode(rsvpCode, data);
    },

    submitOpenRequest(data){
        return sdk.submitOpenRequest(data);
    },

    resetState(env) {
        return {
            guestlistUid: env.VUE_APP_GUEST_LIST_UID,
            rsvpCode: null,
            loading: false,
            eventInformation: null,
            modelData: {},
            guestsData: [],
            recommendationsData: [],
            currentView: 'start',
            registrationType: '',
            responseType: 'confirm',
            openPasswordInvalid: false,
            codeInvalid: false,
            availableResponseOptions: [],
            submitInProgress: false,
            enableGuests: false,
            minGuestCount: 0,
            maxGuestCount: 0,
            waitlistEnabled: false,
            bookingGoesToWaitlist: false
          };
    }

}
